@@ -63,6 +63,9 @@
 #define POLL_PAIRING_TIMEOUT     2000 //mS
 #define POLL_PAIRING_CYCLE       ((POLL_PAIRING_TIMEOUT / 1000) * 2)
 
+#define CHANNEL_RANGE_TO_OPTION_MENU_IDX(range) ((range) - 1)
+#define OPTION_MENU_IDX_TO_CHANNEL_RANGE(menu)  ((menu) + 1)
+
 enum {
     CHANGED,
     LAST_SIGNAL
@@ -695,7 +698,7 @@ static void svp_config_changed(GtkObject *object, gpointer arg1,
     case NV_CTRL_3D_VISION_PRO_TRANSCEIVER_CHANNEL:
         if (HTU(0)->channel_num != event_struct->value) {
             HTU(0)->channel_num = event_struct->value;
-            snprintf(temp, sizeof(temp), "Current Channel ID: %d", HTU(0)->channel_num);
+            snprintf(temp, sizeof(temp), "%d", HTU(0)->channel_num);
             gtk_label_set_text(ctk_3d_vision_pro->channel_num_label, temp);
             gtk_widget_show_all(GTK_WIDGET(ctk_3d_vision_pro->channel_num_label));
         }
@@ -705,12 +708,12 @@ static void svp_config_changed(GtkObject *object, gpointer arg1,
             SVP_RANGE range;
             range = gtk_option_menu_get_history(GTK_OPTION_MENU(ctk_3d_vision_pro->option_menu));
 
-            if (event_struct->value != SVP_INVALID_RANGE && range != event_struct->value) {
+            if (range != CHANNEL_RANGE_TO_OPTION_MENU_IDX(event_struct->value)) {
                 g_signal_handlers_block_by_func(ctk_3d_vision_pro->option_menu,
                     channel_range_changed, ctk_3d_vision_pro);
                 HTU(0)->channel_range = event_struct->value;
                 gtk_option_menu_set_history(GTK_OPTION_MENU(ctk_3d_vision_pro->option_menu),
-                    event_struct->value);
+                    CHANNEL_RANGE_TO_OPTION_MENU_IDX(event_struct->value));
                 enable_widgets(ctk_3d_vision_pro,
                     (HTU(0)->channel_range == SVP_LONG_RANGE ? FALSE : TRUE));
                 g_signal_handlers_unblock_by_func(ctk_3d_vision_pro->option_menu,
@@ -1287,32 +1290,32 @@ static void rename_button_clicked(GtkButton *button, gpointer user_data)
                 }
             }
             if (i == HTU(0)->num_glasses) {
-                goto new_unique_name_set;
+                if (dlg->glasses_selected_index >= 0 &&
+                    dlg->glasses_selected_index < HTU(0)->num_glasses) {
+                    Bool ret;
+                    unsigned int glasses_id = HTU(0)->glasses_info[dlg->glasses_selected_index]->glasses_id;
+
+                    ret = XNVCTRLSetTargetStringAttribute(NvCtrlGetDisplayPtr(ctk_3d_vision_pro->handle),
+                                                          NV_CTRL_TARGET_TYPE_3D_VISION_PRO_TRANSCEIVER,
+                                                          0, glasses_id,
+                                                          NV_CTRL_STRING_3D_VISION_PRO_GLASSES_NAME,
+                                                          dlg->glasses_new_name);
+
+                    if (ret == False) {
+                        continue;
+                    }
+                    strncpy(HTU(0)->glasses_info[dlg->glasses_selected_index]->name, dlg->glasses_new_name,
+                            sizeof(HTU(0)->glasses_info[dlg->glasses_selected_index]->name));
+                    HTU(0)->glasses_info[dlg->glasses_selected_index]->name[GLASSES_NAME_MAX_LENGTH - 1] = '\0';
+
+                    update_glasses_info_data_table(&(ctk_3d_vision_pro->table), HTU(0)->glasses_info);
+                    gtk_widget_show_all(GTK_WIDGET(ctk_3d_vision_pro->table.data_table));
+                }
+                break;
             }
         }
 
     } while (result != GTK_RESPONSE_REJECT);
-    goto no_name_set;
-
-new_unique_name_set:
-    if (dlg->glasses_selected_index >= 0 &&
-        dlg->glasses_selected_index < HTU(0)->num_glasses) {
-        unsigned int glasses_id = HTU(0)->glasses_info[dlg->glasses_selected_index]->glasses_id;
-
-        XNVCTRLSetTargetStringAttribute(NvCtrlGetDisplayPtr(ctk_3d_vision_pro->handle),
-                                        NV_CTRL_TARGET_TYPE_3D_VISION_PRO_TRANSCEIVER,
-                                        0, glasses_id,
-                                        NV_CTRL_STRING_3D_VISION_PRO_GLASSES_NAME,
-                                        dlg->glasses_new_name);
-
-        strncpy(HTU(0)->glasses_info[dlg->glasses_selected_index]->name, dlg->glasses_new_name,
-                sizeof(HTU(0)->glasses_info[dlg->glasses_selected_index]->name));
-        HTU(0)->glasses_info[dlg->glasses_selected_index]->name[GLASSES_NAME_MAX_LENGTH - 1] = '\0';
-
-        update_glasses_info_data_table(&(ctk_3d_vision_pro->table), HTU(0)->glasses_info);
-        gtk_widget_show_all(GTK_WIDGET(ctk_3d_vision_pro->table.data_table));
-    }
-no_name_set:
 
     gtk_widget_hide(dlg->dlg_rename_glasses);
 
@@ -1368,9 +1371,6 @@ static ChannelRangeDlg *create_channel_range_change_dlg(Ctk3DVisionPro *ctk_3d_v
                               "Only glasses in this range will be available.\n\n"
                               "Do you want to apply changes?");
         break;
-    case SVP_INVALID_RANGE:
-        label = gtk_label_new("Invalid selection.\n");
-        break;
     }
 
     hbox = gtk_hbox_new(TRUE, 0);
@@ -1397,16 +1397,12 @@ static void channel_range_changed(
     SVP_RANGE range;
     SVP_RANGE prev_range;
 
-    range = gtk_option_menu_get_history(option_menu);
+    range = OPTION_MENU_IDX_TO_CHANNEL_RANGE(gtk_option_menu_get_history(option_menu));
     prev_range = HTU(0)->channel_range;
 
     if (HTU(0)->channel_range == range) {
         return;
     }
-    if (range == SVP_INVALID_RANGE) {
-        gtk_option_menu_set_history(GTK_OPTION_MENU(ctk_3d_vision_pro->option_menu), prev_range);
-        return;
-    }
 
     dlg = create_channel_range_change_dlg(ctk_3d_vision_pro, range);
 
@@ -1437,7 +1433,8 @@ static void channel_range_changed(
 
         break;
     case GTK_RESPONSE_NO:
-        gtk_option_menu_set_history(GTK_OPTION_MENU(ctk_3d_vision_pro->option_menu), prev_range);
+        gtk_option_menu_set_history(GTK_OPTION_MENU(ctk_3d_vision_pro->option_menu), 
+                                    CHANNEL_RANGE_TO_OPTION_MENU_IDX(prev_range));
         break;
     default:
         /* do nothing. */
@@ -1516,15 +1513,11 @@ GtkWidget* ctk_3d_vision_pro_new(NvCtrlAttributeHandle *handle,
                                       0, 0,
                                       NV_CTRL_3D_VISION_PRO_TRANSCEIVER_MODE,
                                       (int *)&(HTU(0)->channel_range));
-    if (ret != TRUE) {
-        HTU(0)->channel_range = SVP_INVALID_RANGE;
-    }
-
-    // validate channel range
-    if (!(HTU(0)->channel_range == SVP_SHORT_RANGE ||
+    if (ret != TRUE ||
+        (!(HTU(0)->channel_range == SVP_SHORT_RANGE ||
           HTU(0)->channel_range == SVP_MEDIUM_RANGE ||
-          HTU(0)->channel_range == SVP_LONG_RANGE)) {
-        HTU(0)->channel_range = SVP_INVALID_RANGE;
+          HTU(0)->channel_range == SVP_LONG_RANGE))) {
+        HTU(0)->channel_range = SVP_SHORT_RANGE;
     }
 
     ret = XNVCTRLQueryTargetBinaryData(NvCtrlGetDisplayPtr(ctk_3d_vision_pro->handle), 
@@ -1703,10 +1696,9 @@ GtkWidget* ctk_3d_vision_pro_new(NvCtrlAttributeHandle *handle,
 
     hbox = gtk_hbox_new(FALSE, 5);
     menu = gtk_menu_new();
-    add_menu_item(menu, "Invalid Range");
-    add_menu_item(menu, "Short Range (up to 2 meter)");
-    add_menu_item(menu, "Medium Range (up to 10 meter)");
-    add_menu_item(menu, "Long Range");
+    add_menu_item(menu, "Short Range (upto 5 meter)");
+    add_menu_item(menu, "Medium Range (upto 15 meter)");
+    add_menu_item(menu, "Long Range (upto 30 meter)");
     ctk_3d_vision_pro->option_menu = gtk_option_menu_new ();
     gtk_option_menu_set_menu
         (GTK_OPTION_MENU(ctk_3d_vision_pro->option_menu), menu);
@@ -1721,7 +1713,7 @@ GtkWidget* ctk_3d_vision_pro_new(NvCtrlAttributeHandle *handle,
                       "channel_range", GINT_TO_POINTER(0));
 
     gtk_option_menu_set_history(GTK_OPTION_MENU(ctk_3d_vision_pro->option_menu),
-                                HTU(0)->channel_range);
+                                CHANNEL_RANGE_TO_OPTION_MENU_IDX(HTU(0)->channel_range));
     g_signal_connect(G_OBJECT(ctk_3d_vision_pro->option_menu), "changed",
                      G_CALLBACK(channel_range_changed),
                      (gpointer) ctk_3d_vision_pro);
@@ -1846,7 +1838,8 @@ GtkTextBuffer *ctk_3d_vision_pro_create_help(GtkTextTagTable *table)
     ctk_help_para(b, &i, __goggle_info_tooltip);
 
     ctk_help_heading(b, &i, "Glasses Name");
-    ctk_help_para(b, &i, "Each pair of glasses has an unique name. "
+    ctk_help_para(b, &i, "Each pair of glasses has an unique name and the name should "
+                         "start and end with an alpha-numeric character. "
                          "Glasses can be renamed using Rename button.");
 
     ctk_help_heading(b, &i, "Battery Level");
@@ -1887,7 +1880,7 @@ GtkTextBuffer *ctk_3d_vision_pro_create_help(GtkTextTagTable *table)
     ctk_help_para(b, &i, "Medium Range: \n"
                          "Allows glasses within a 10-meter (32-foot) range to "
                          "be synced with the hub. This range is typically used "
-                         "for sharing a presentation with a limited audience. or "
+                         "for sharing a presentation with a limited audience or "
                          "interacting with 3D CAD models during a collaborative "
                          "design session.");
     ctk_help_para(b, &i, "Long Range: \n"
